Struct IpAddressesUpdated
pub struct IpAddressesUpdated {
pub index: u64,
pub ingress: String,
pub egress: String,
pub caller: Address,
}Expand description
Event with signature IpAddressesUpdated(uint64,string,string,address) and selector 0x241dec1e5ad7db0fa5d3d80c9fb8362e665dd623a4453decff244990e5db64b4.
event IpAddressesUpdated(uint64 indexed index, string ingress, string egress, address caller);Fields
index: u64ingress: Stringegress: Stringcaller: AddressTrait Implementations
impl Clone for IpAddressesUpdated
impl Clone for IpAddressesUpdated
fn clone(&self) -> IpAddressesUpdated
fn clone(&self) -> IpAddressesUpdated
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for IpAddressesUpdated
impl Debug for IpAddressesUpdated
impl<'de> Deserialize<'de> for IpAddressesUpdated
impl<'de> Deserialize<'de> for IpAddressesUpdated
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IpAddressesUpdated, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<IpAddressesUpdated, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl IntoLogData for IpAddressesUpdated
impl IntoLogData for IpAddressesUpdated
fn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
Convert into a [
LogData] object.fn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
Consume and convert into a [
LogData] object.impl JsonAbiExt for IpAddressesUpdated
impl JsonAbiExt for IpAddressesUpdated
fn abi() -> <IpAddressesUpdated as JsonAbiExt>::Abi
fn abi() -> <IpAddressesUpdated as JsonAbiExt>::Abi
Returns the ABI representation of this type.
impl PartialEq for IpAddressesUpdated
impl PartialEq for IpAddressesUpdated
impl Serialize for IpAddressesUpdated
impl Serialize for IpAddressesUpdated
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl SolEvent for IpAddressesUpdated
impl SolEvent for IpAddressesUpdated
const SIGNATURE: &'static str = "IpAddressesUpdated(uint64,string,string,address)"
const SIGNATURE: &'static str = "IpAddressesUpdated(uint64,string,string,address)"
The event’s ABI signature. Read more
const SIGNATURE_HASH: FixedBytes<32>
const SIGNATURE_HASH: FixedBytes<32>
The event’s ABI signature hash, or selector:
keccak256(SIGNATURE) Read moretype DataTuple<'a> = (String, String, Address)
type DataTuple<'a> = (String, String, Address)
The underlying tuple type which represents this event’s non-indexed
parameters. These parameters are ABI encoded and included in the log
body. Read more
type DataToken<'a> = <<IpAddressesUpdated as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
type DataToken<'a> = <<IpAddressesUpdated as SolEvent>::DataTuple<'a> as SolType>::Token<'a>
The [
TokenSeq] type corresponding to the tuple.type TopicList = (FixedBytes<32>, Uint<64>)
type TopicList = (FixedBytes<32>, Uint<64>)
The underlying tuple type which represents this event’s topics. Read more
fn new(
topics: <<IpAddressesUpdated as SolEvent>::TopicList as SolType>::RustType,
data: <<IpAddressesUpdated as SolEvent>::DataTuple<'_> as SolType>::RustType,
) -> IpAddressesUpdated
fn new( topics: <<IpAddressesUpdated as SolEvent>::TopicList as SolType>::RustType, data: <<IpAddressesUpdated as SolEvent>::DataTuple<'_> as SolType>::RustType, ) -> IpAddressesUpdated
Convert decoded rust data to the event type. Read more
fn check_signature(
topics: &<<IpAddressesUpdated as SolEvent>::TopicList as SolType>::RustType,
) -> Result<(), Error>
fn check_signature( topics: &<<IpAddressesUpdated as SolEvent>::TopicList as SolType>::RustType, ) -> Result<(), Error>
Check that the event’s signature matches the given topics.
fn tokenize_body(&self) -> <IpAddressesUpdated as SolEvent>::DataToken<'_>
fn tokenize_body(&self) -> <IpAddressesUpdated as SolEvent>::DataToken<'_>
Tokenize the event’s non-indexed parameters.
fn topics(
&self,
) -> <<IpAddressesUpdated as SolEvent>::TopicList as SolType>::RustType
fn topics( &self, ) -> <<IpAddressesUpdated as SolEvent>::TopicList as SolType>::RustType
The event’s topics.
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
fn encode_topics_raw(&self, out: &mut [WordToken]) -> Result<(), Error>
Encode the topics of this event into the given buffer. Read more
fn new_checked(
topics: <Self::TopicList as SolType>::RustType,
data: <Self::DataTuple<'_> as SolType>::RustType,
) -> Result<Self, Error>
fn new_checked( topics: <Self::TopicList as SolType>::RustType, data: <Self::DataTuple<'_> as SolType>::RustType, ) -> Result<Self, Error>
Convert decoded rust data to the event type. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the ABI-encoded dynamic data in bytes.
fn encode_data_to(&self, out: &mut Vec<u8>)
fn encode_data_to(&self, out: &mut Vec<u8>)
ABI-encode the dynamic data of this event into the given buffer.
fn encode_data(&self) -> Vec<u8> ⓘ
fn encode_data(&self) -> Vec<u8> ⓘ
ABI-encode the dynamic data of this event.
fn encode_topics(&self) -> Vec<WordToken>
fn encode_topics(&self) -> Vec<WordToken>
Encode the topics of this event. Read more
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
fn encode_topics_array<const LEN: usize>(&self) -> [WordToken; LEN]
Encode the topics of this event into a fixed-size array. Read more
fn encode_log_data(&self) -> LogData
fn encode_log_data(&self) -> LogData
Encode this event to a [
LogData].fn encode_log(log: &Log<Self>) -> Log
fn encode_log(log: &Log<Self>) -> Log
Transform ca [
Log] containing this event into a [Log] containing
[LogData].fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_topics<I, D>(
topics: I,
) -> Result<<Self::TopicList as SolType>::RustType, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
Decode the topics of this event from the given data.
fn abi_decode_data<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer.
fn abi_decode_data_validate<'a>(
data: &'a [u8],
) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
fn abi_decode_data_validate<'a>( data: &'a [u8], ) -> Result<<Self::DataTuple<'a> as SolType>::RustType, Error>
ABI-decodes the dynamic data of this event from the given buffer, with validation. Read more
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
Decode the event from the given log info.
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
fn decode_raw_log_validate<I, D>(topics: I, data: &[u8]) -> Result<Self, Error>where
I: IntoIterator<Item = D>,
D: Into<WordToken>,
Decode the event from the given log info, with validation. Read more
fn decode_log_data(log: &LogData) -> Result<Self, Error>
fn decode_log_data(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object.
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
fn decode_log_data_validate(log: &LogData) -> Result<Self, Error>
Decode the event from the given log object with validation.
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
Decode the event from the given log object.
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
fn decode_log_validate(log: &Log) -> Result<Log<Self>, Error>
Decode the event from the given log object with validation.
impl Eq for IpAddressesUpdated
impl StructuralPartialEq for IpAddressesUpdated