Struct IValidatorConfigV2Instance
pub struct IValidatorConfigV2Instance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A IValidatorConfigV2 instance.
Contains type-safe methods for interacting with an on-chain instance of the
IValidatorConfigV2 contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Instantiation and getters/setters.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Instantiation and getters/setters.
pub const fn new(
address: Address,
__provider: P,
) -> IValidatorConfigV2Instance<P, N>
pub const fn new( address: Address, __provider: P, ) -> IValidatorConfigV2Instance<P, N>
Creates a new wrapper around an on-chain IValidatorConfigV2 contract instance.
See the wrapper’s documentation for more details.
pub const fn address(&self) -> &Address
pub const fn address(&self) -> &Address
Returns a reference to the address.
pub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
pub fn at(self, address: Address) -> IValidatorConfigV2Instance<P, N>
pub fn at(self, address: Address) -> IValidatorConfigV2Instance<P, N>
Sets the address and returns self.
impl<P, N> IValidatorConfigV2Instance<&P, N>where
P: Clone,
impl<P, N> IValidatorConfigV2Instance<&P, N>where
P: Clone,
pub fn with_cloned_provider(self) -> IValidatorConfigV2Instance<P, N>
pub fn with_cloned_provider(self) -> IValidatorConfigV2Instance<P, N>
Clones the provider and returns a new instance with the cloned provider.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Function calls.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Function calls.
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
pub fn getActiveValidators(
&self,
) -> CallBuilder<&P, PhantomData<getActiveValidatorsCall>, N>
pub fn getActiveValidators( &self, ) -> CallBuilder<&P, PhantomData<getActiveValidatorsCall>, N>
Creates a new call builder for the [getActiveValidators] function.
pub fn getInitializedAtHeight(
&self,
) -> CallBuilder<&P, PhantomData<getInitializedAtHeightCall>, N>
pub fn getInitializedAtHeight( &self, ) -> CallBuilder<&P, PhantomData<getInitializedAtHeightCall>, N>
Creates a new call builder for the [getInitializedAtHeight] function.
pub fn owner(&self) -> CallBuilder<&P, PhantomData<ownerCall>, N>
pub fn owner(&self) -> CallBuilder<&P, PhantomData<ownerCall>, N>
Creates a new call builder for the [owner] function.
pub fn validatorCount(
&self,
) -> CallBuilder<&P, PhantomData<validatorCountCall>, N>
pub fn validatorCount( &self, ) -> CallBuilder<&P, PhantomData<validatorCountCall>, N>
Creates a new call builder for the [validatorCount] function.
pub fn validatorByIndex(
&self,
index: u64,
) -> CallBuilder<&P, PhantomData<validatorByIndexCall>, N>
pub fn validatorByIndex( &self, index: u64, ) -> CallBuilder<&P, PhantomData<validatorByIndexCall>, N>
Creates a new call builder for the [validatorByIndex] function.
pub fn validatorByAddress(
&self,
validatorAddress: Address,
) -> CallBuilder<&P, PhantomData<validatorByAddressCall>, N>
pub fn validatorByAddress( &self, validatorAddress: Address, ) -> CallBuilder<&P, PhantomData<validatorByAddressCall>, N>
Creates a new call builder for the [validatorByAddress] function.
pub fn validatorByPublicKey(
&self,
publicKey: FixedBytes<32>,
) -> CallBuilder<&P, PhantomData<validatorByPublicKeyCall>, N>
pub fn validatorByPublicKey( &self, publicKey: FixedBytes<32>, ) -> CallBuilder<&P, PhantomData<validatorByPublicKeyCall>, N>
Creates a new call builder for the [validatorByPublicKey] function.
pub fn getNextNetworkIdentityRotationEpoch(
&self,
) -> CallBuilder<&P, PhantomData<getNextNetworkIdentityRotationEpochCall>, N>
pub fn getNextNetworkIdentityRotationEpoch( &self, ) -> CallBuilder<&P, PhantomData<getNextNetworkIdentityRotationEpochCall>, N>
Creates a new call builder for the [getNextNetworkIdentityRotationEpoch] function.
pub fn isInitialized(
&self,
) -> CallBuilder<&P, PhantomData<isInitializedCall>, N>
pub fn isInitialized( &self, ) -> CallBuilder<&P, PhantomData<isInitializedCall>, N>
Creates a new call builder for the [isInitialized] function.
pub fn addValidator(
&self,
validatorAddress: Address,
publicKey: FixedBytes<32>,
ingress: String,
egress: String,
feeRecipient: Address,
signature: Bytes,
) -> CallBuilder<&P, PhantomData<addValidatorCall>, N>
pub fn addValidator( &self, validatorAddress: Address, publicKey: FixedBytes<32>, ingress: String, egress: String, feeRecipient: Address, signature: Bytes, ) -> CallBuilder<&P, PhantomData<addValidatorCall>, N>
Creates a new call builder for the [addValidator] function.
pub fn deactivateValidator(
&self,
idx: u64,
) -> CallBuilder<&P, PhantomData<deactivateValidatorCall>, N>
pub fn deactivateValidator( &self, idx: u64, ) -> CallBuilder<&P, PhantomData<deactivateValidatorCall>, N>
Creates a new call builder for the [deactivateValidator] function.
pub fn rotateValidator(
&self,
idx: u64,
publicKey: FixedBytes<32>,
ingress: String,
egress: String,
signature: Bytes,
) -> CallBuilder<&P, PhantomData<rotateValidatorCall>, N>
pub fn rotateValidator( &self, idx: u64, publicKey: FixedBytes<32>, ingress: String, egress: String, signature: Bytes, ) -> CallBuilder<&P, PhantomData<rotateValidatorCall>, N>
Creates a new call builder for the [rotateValidator] function.
pub fn setFeeRecipient(
&self,
idx: u64,
feeRecipient: Address,
) -> CallBuilder<&P, PhantomData<setFeeRecipientCall>, N>
pub fn setFeeRecipient( &self, idx: u64, feeRecipient: Address, ) -> CallBuilder<&P, PhantomData<setFeeRecipientCall>, N>
Creates a new call builder for the [setFeeRecipient] function.
pub fn setIpAddresses(
&self,
idx: u64,
ingress: String,
egress: String,
) -> CallBuilder<&P, PhantomData<setIpAddressesCall>, N>
pub fn setIpAddresses( &self, idx: u64, ingress: String, egress: String, ) -> CallBuilder<&P, PhantomData<setIpAddressesCall>, N>
Creates a new call builder for the [setIpAddresses] function.
pub fn transferValidatorOwnership(
&self,
idx: u64,
newAddress: Address,
) -> CallBuilder<&P, PhantomData<transferValidatorOwnershipCall>, N>
pub fn transferValidatorOwnership( &self, idx: u64, newAddress: Address, ) -> CallBuilder<&P, PhantomData<transferValidatorOwnershipCall>, N>
Creates a new call builder for the [transferValidatorOwnership] function.
pub fn transferOwnership(
&self,
newOwner: Address,
) -> CallBuilder<&P, PhantomData<transferOwnershipCall>, N>
pub fn transferOwnership( &self, newOwner: Address, ) -> CallBuilder<&P, PhantomData<transferOwnershipCall>, N>
Creates a new call builder for the [transferOwnership] function.
pub fn setNetworkIdentityRotationEpoch(
&self,
epoch: u64,
) -> CallBuilder<&P, PhantomData<setNetworkIdentityRotationEpochCall>, N>
pub fn setNetworkIdentityRotationEpoch( &self, epoch: u64, ) -> CallBuilder<&P, PhantomData<setNetworkIdentityRotationEpochCall>, N>
Creates a new call builder for the [setNetworkIdentityRotationEpoch] function.
pub fn migrateValidator(
&self,
idx: u64,
) -> CallBuilder<&P, PhantomData<migrateValidatorCall>, N>
pub fn migrateValidator( &self, idx: u64, ) -> CallBuilder<&P, PhantomData<migrateValidatorCall>, N>
Creates a new call builder for the [migrateValidator] function.
pub fn initializeIfMigrated(
&self,
) -> CallBuilder<&P, PhantomData<initializeIfMigratedCall>, N>
pub fn initializeIfMigrated( &self, ) -> CallBuilder<&P, PhantomData<initializeIfMigratedCall>, N>
Creates a new call builder for the [initializeIfMigrated] function.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Event filters.
impl<P, N> IValidatorConfigV2Instance<P, N>where
P: Provider<N>,
N: Network,
Event filters.
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
pub fn ValidatorAdded_filter(&self) -> Event<&P, ValidatorAdded, N>
pub fn ValidatorAdded_filter(&self) -> Event<&P, ValidatorAdded, N>
Creates a new event filter for the ValidatorAdded event.
pub fn ValidatorDeactivated_filter(&self) -> Event<&P, ValidatorDeactivated, N>
pub fn ValidatorDeactivated_filter(&self) -> Event<&P, ValidatorDeactivated, N>
Creates a new event filter for the ValidatorDeactivated event.
pub fn ValidatorRotated_filter(&self) -> Event<&P, ValidatorRotated, N>
pub fn ValidatorRotated_filter(&self) -> Event<&P, ValidatorRotated, N>
Creates a new event filter for the ValidatorRotated event.
pub fn FeeRecipientUpdated_filter(&self) -> Event<&P, FeeRecipientUpdated, N>
pub fn FeeRecipientUpdated_filter(&self) -> Event<&P, FeeRecipientUpdated, N>
Creates a new event filter for the FeeRecipientUpdated event.
pub fn IpAddressesUpdated_filter(&self) -> Event<&P, IpAddressesUpdated, N>
pub fn IpAddressesUpdated_filter(&self) -> Event<&P, IpAddressesUpdated, N>
Creates a new event filter for the IpAddressesUpdated event.
pub fn ValidatorOwnershipTransferred_filter(
&self,
) -> Event<&P, ValidatorOwnershipTransferred, N>
pub fn ValidatorOwnershipTransferred_filter( &self, ) -> Event<&P, ValidatorOwnershipTransferred, N>
Creates a new event filter for the ValidatorOwnershipTransferred event.
pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
pub fn OwnershipTransferred_filter(&self) -> Event<&P, OwnershipTransferred, N>
Creates a new event filter for the OwnershipTransferred event.
pub fn ValidatorMigrated_filter(&self) -> Event<&P, ValidatorMigrated, N>
pub fn ValidatorMigrated_filter(&self) -> Event<&P, ValidatorMigrated, N>
Creates a new event filter for the ValidatorMigrated event.
pub fn NetworkIdentityRotationEpochSet_filter(
&self,
) -> Event<&P, NetworkIdentityRotationEpochSet, N>
pub fn NetworkIdentityRotationEpochSet_filter( &self, ) -> Event<&P, NetworkIdentityRotationEpochSet, N>
Creates a new event filter for the NetworkIdentityRotationEpochSet event.
pub fn Initialized_filter(&self) -> Event<&P, Initialized, N>
pub fn Initialized_filter(&self) -> Event<&P, Initialized, N>
Creates a new event filter for the Initialized event.
pub fn SkippedValidatorMigration_filter(
&self,
) -> Event<&P, SkippedValidatorMigration, N>
pub fn SkippedValidatorMigration_filter( &self, ) -> Event<&P, SkippedValidatorMigration, N>
Creates a new event filter for the SkippedValidatorMigration event.